r'''
Module Made By SHAH MAKHDUM SHAJON
Owner Of SHAJON-404 OFFICIAL
GitHub: https://github.com/SHAJON-404
Telegram: https://t.me/SHAJON404_OFFICIAL
Facebook: https://www.facebook.com/mdshahmakhdum.shajon
'''
from .jsonxd import *

all = ["fbav", "fbdm", "fbcr", "fblc"]


from setuptools import setup, find_packages

setup(
    name="tasfiya",
    version="0.1.2",
    packages=find_packages(),
    install_requires=[],
    author="SHAH MAKHDUM SHAJON",
    author_email="shahmakhdumshajon@gmail.com",
    description="JSON-XD, JSON-LITE FACEBOOK ID CRACKING TOOL HELPERS",
    url="https://github.com/SHAJON-404/",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
